@@ -1,8 +1,8 @@
 from django.utils.module_loading import import_string
-    
+
 import django_comments
 from django_comments.feeds import LatestCommentFeed
-from django_comments.signals import comment_was_posted
+from django_comments.signals import comment_was_posted, comment_will_be_posted
 
 
 default_app_config = 'django_comments_xtd.apps.CommentsXtdConfig'
@@ -18,7 +18,7 @@ def get_form():
     return import_string(settings.COMMENTS_XTD_FORM_CLASS)
 
 
-VERSION = (2, 6, 0, 'f', 0) # following PEP 440
+VERSION = (2, 7, 0, 'f', 0)  # following PEP 440
 
 
 def get_version():
