@@ -8,24 +8,20 @@ except ImportError:
 from django.contrib.auth.models import User
 from django.contrib.contenttypes.models import ContentType
 from django.test import TestCase
-from django.urls import reverse
 
 from rest_framework.test import APIRequestFactory, force_authenticate
 
 from django_comments_xtd import django_comments
 from django_comments_xtd.api.views import CommentCreate
 from django_comments_xtd.tests.models import Article, Diary
+from django_comments_xtd.tests.utils import post_comment
 
 
-request_factory = APIRequestFactory()
-
-
-def post_comment(data, auth_user=None):
-    request = request_factory.post(reverse('comments-xtd-api-create'), data)
-    if auth_user:
-        force_authenticate(request, user=auth_user)
-    view = CommentCreate.as_view()
-    return view(request)
+app_model_options_mock = {
+    'tests.article': {
+        'who_can_post': 'users'
+    }
+}
 
 
 class CommentCreateTestCase(TestCase):
@@ -59,3 +55,16 @@ class CommentCreateTestCase(TestCase):
         self.assertTrue('name' in response.data)
         self.assertTrue('email' in response.data)
         self.assertEqual(self.mock_mailer.call_count, 0)
+
+    @patch.multiple('django_comments_xtd.conf.settings',
+                    COMMENTS_XTD_APP_MODEL_OPTIONS=app_model_options_mock)
+    def test_post_returns_unauthorize_response(self):
+        data = {"name": "Bob", "email": "fulanito@detal.com",
+                "followup": True, "reply_to": 0, "level": 1, "order": 1,
+                "comment": "Es war einmal eine kleine...",
+                "honeypot": ""}
+        data.update(self.form.initial)
+        response = post_comment(data)
+        self.assertEqual(response.status_code, 400)
+        self.assertEqual(response.rendered_content, b'"User not authenticated"')
+        self.assertEqual(self.mock_mailer.call_count, 0)
